==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXProfilesDB.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXProfilesDB;no warnings;require NXPaths;sub BEGIN{require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}sub BEGIN{require 
Exception::Log;do{"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4c\x6f\x67"->
import};}(my $__databaseInitialized=(0x181d+ 2677-0x2292));(my $__userSidsInitialized
=(0x0060+   9-0x0069));(my (%__profiles)=());(my (%__loadedProfiles)=());(my $__fields_in_record
=(0x09a7+ 1678-0x101b));sub save{Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x53\x61\x76\x69\x6e\x67\x20\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e"
);if ((not (%__profiles))){NXRedis::sendToDbAndSave (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);}else{my ($command);foreach my $key (keys (%__profiles)){(my $line=join (
"\x3a",@{$__profiles{$key};}));(my $record=main::urlencode ($line));($key=
main::urlencode ($key));if (($record ne $__loadedProfiles{$key})){($command.=(((
"\x2c\x66\x69\x65\x6c\x64\x3d".$key)."\x2c\x76\x61\x6c\x75\x65\x3d").$record));}
delete ($__loadedProfiles{$key});(my $length=length ($command));if (($length>
15000)){NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$command)."\x0a"));($command=(""));}}if (($command ne (""))){
NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$command)."\x0a"));}if (%__loadedProfiles){my ($commandDel);foreach my $key (
keys (%__loadedProfiles)){($commandDel.=("\x2c\x66\x69\x65\x6c\x64\x3d".$key));}
if (($commandDel ne (""))){NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$commandDel)."\x0a"));}}resetDB ();}return ((0x00d0+ 7365-0x1d95));}sub __load{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x67\x65\x74\x61\x6c\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);((%__loadedProfiles)=split ( / / ,NXRedis::get (),(0x1258+ 4393-0x2381)));
foreach my $key (keys (%__loadedProfiles)){(my $record=main::urldecode (
$__loadedProfiles{$key}));($key=main::urldecode ($key));(my (@recordArray)=split
 ( /:/ ,$record,(0x0b73+ 5185-0x1fb4)));($__profiles{$key}=(\@recordArray));}
__convertUsernamesInKeysToAbsoluteUsername ();($__databaseInitialized=
(0x099c+ 5479-0x1f02));}sub getDatabaseInString{__load ();(my $string=
NXShell::hashParameters2Url (%__loadedProfiles));return ($string);}sub 
setDatabaseByString{(my $string=shift (@_));if (($string eq (""))){return (
(0x0205+ 8742-0x242b));}(my (%tmpProfiles)=NXShell::urlParameter2Hash ($string))
;foreach my $key (keys (%tmpProfiles)){(my (@recordArray)=split ( /:/ ,
main::urldecode ($tmpProfiles{$key}),(0x140f+ 1077-0x1844)));($__profiles{$key}=
(\@recordArray));}save ();return ((0x1b3b+ 2023-0x2322));}sub cleanDb{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);resetDB ();((%__loadedProfiles)=());}sub getDatabaseReference{if ((
$__databaseInitialized==(0x0216+ 2542-0x0c04))){__load ();}return ((\%__profiles
));}sub getEmptyProfile{return ((((""))x $__fields_in_record));}sub resetDB{
Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x52\x65\x73\x65\x74\x69\x6e\x67\x20\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e"
);($__databaseInitialized=(0x114d+ 3692-0x1fb9));foreach my $key (keys (
%__profiles)){delete ($__profiles{$key});}}sub 
__convertUsernamesInKeysToAbsoluteUsername{if ((($__userSidsInitialized==
(0x106b+ 2115-0x18ad))or ($GLOBAL::DisableUsernameConversion==
(0x0f5d+ 3767-0x1e13)))){return;}Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x43\x6f\x6e\x76\x65\x72\x74\x69\x6e\x67\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x73\x20\x74\x6f\x20\x53\x49\x44\x73\x2e"
);foreach my $key (keys (%__profiles)){(my $convertedKey=$key);
convertUsernameInKeyToAbsoluteUsername ((\$convertedKey));if (($convertedKey ne 
$key)){($__profiles{$convertedKey}=$__profiles{$key});delete ($__profiles{$key})
;}}($__userSidsInitialized=(0x07d1+ 7553-0x2551));}sub 
convertUsernameInKeyToAbsoluteUsername{if (($GLOBAL::DisableUsernameConversion==
(0x00b3+ 8714-0x22bc))){return;}(my $ref_key=shift (@_));if ((
__convertUsernameInNodeAndUserProfileKeyToAbsoluteUsername ($ref_key)==
(0x176a+ 1054-0x1b87))){return;}if ((
__convertUsernameInUserProfileKeyToAbsoluteUsername ($ref_key)==
(0x014c+ 677-0x03f0))){return;}}sub 
__convertUsernameInNodeAndUserProfileKeyToAbsoluteUsername{(my $ref_key=shift (
@_));if (($$ref_key=~ /(.*),(.*)/ )){(my $node=$1);(my $user=$2);if (($node=~ /\// )
){if ((__convertUsernameInUserProfileKeyToAbsoluteUsername ((\$user))==
(0x04f3+ 7191-0x2109))){($$ref_key=(($node."\x2c").$user));}}return (
(0x071f+ 397-0x08ab));}return ((0x0c16+ 5106-0x2008));}sub 
__convertUsernameInUserProfileKeyToAbsoluteUsername{(my $ref_key=shift (@_));if 
(NXProfiles::isInternalKey ($$ref_key)){return ((0x0dd7+ 3833-0x1cd0));}if ((
$$ref_key=~ /__group__/ )){return ((0x0fd1+ 5248-0x2451));}if (($$ref_key=~ /\// )
){return ((0x0862+ 2036-0x1056));}if (($$ref_key=~ /__nodegroup__/ )){return (
(0x13bc+ 3537-0x218d));}if (($$ref_key=~ /__servergroup__/ )){return (
(0x0117+ 7227-0x1d52));}if (($$ref_key=~ /__address__/ )){return (
(0x1403+  81-0x1454));}(my $username=NXLogin::getAbsoluteNameForUsername (
$$ref_key));($$ref_key=$username);return ((0x1766+ 1996-0x1f31));}sub 
reloadProfilesDB{($__databaseInitialized=(0x0b04+ 100-0x0b68));(
$__userSidsInitialized=(0x03ed+ 7154-0x1fdf));((%__profiles)=());__load ();if (
NXProfiles::isPropagatedRuleToOverwrite ()){NXProfiles::overwritePropagatedRules
 ();}}"\x3f\x3f\x3f";

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXProfilesDB.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXProfilesDB;no warnings;require NXPaths;sub BEGIN{require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}sub BEGIN{require 
Exception::Log;do{"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4c\x6f\x67"->
import};}(my $__databaseInitialized=(0x0311+ 4944-0x1661));(my $__userSidsInitialized
=(0x032c+ 348-0x0488));(my (%__profiles)=());(my (%__loadedProfiles)=());(my $__fields_in_record
=(0x08a5+ 4361-0x1994));sub save{Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x53\x61\x76\x69\x6e\x67\x20\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e"
);if ((not (%__profiles))){NXRedis::sendToDbAndSave (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);}else{my ($command);foreach my $key (keys (%__profiles)){(my $line=join (
"\x3a",@{$__profiles{$key};}));(my $record=main::urlencode ($line));($key=
main::urlencode ($key));if (($record ne $__loadedProfiles{$key})){($command.=(((
"\x2c\x66\x69\x65\x6c\x64\x3d".$key)."\x2c\x76\x61\x6c\x75\x65\x3d").$record));}
delete ($__loadedProfiles{$key});(my $length=length ($command));if (($length>
15000)){NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$command)."\x0a"));($command=(""));}}if (($command ne (""))){
NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x6d\x73\x65\x74\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$command)."\x0a"));}if (%__loadedProfiles){my ($commandDel);foreach my $key (
keys (%__loadedProfiles)){($commandDel.=("\x2c\x66\x69\x65\x6c\x64\x3d".$key));}
if (($commandDel ne (""))){NXRedis::sendToDbAndSave (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73"
.$commandDel)."\x0a"));}}resetDB ();}return ((0x11cc+ 2986-0x1d76));}sub __load{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x68\x67\x65\x74\x61\x6c\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);((%__loadedProfiles)=split ( / / ,NXRedis::get (),(0x1aef+ 464-0x1cbf)));
foreach my $key (keys (%__loadedProfiles)){(my $record=main::urldecode (
$__loadedProfiles{$key}));($key=main::urldecode ($key));(my (@recordArray)=split
 ( /:/ ,$record,(0x0589+ 8130-0x254b)));($__profiles{$key}=(\@recordArray));}
__convertUsernamesInKeysToAbsoluteUsername ();($__databaseInitialized=
(0x0862+ 3386-0x159b));}sub getDatabaseInString{__load ();(my $string=
NXShell::hashParameters2Url (%__loadedProfiles));return ($string);}sub 
setDatabaseByString{(my $string=shift (@_));if (($string eq (""))){return (
(0x0438+ 1309-0x0955));}(my (%tmpProfiles)=NXShell::urlParameter2Hash ($string))
;foreach my $key (keys (%tmpProfiles)){(my (@recordArray)=split ( /:/ ,
main::urldecode ($tmpProfiles{$key}),(0x0997+ 6166-0x21ad)));($__profiles{$key}=
(\@recordArray));}save ();return ((0x0081+ 4800-0x1341));}sub cleanDb{
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x70\x72\x6f\x66\x69\x6c\x65\x73\x0a"
);resetDB ();((%__loadedProfiles)=());}sub getDatabaseReference{if ((
$__databaseInitialized==(0x12e9+ 444-0x14a5))){__load ();}return ((\%__profiles)
);}sub getEmptyProfile{return ((((""))x $__fields_in_record));}sub resetDB{
Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x52\x65\x73\x65\x74\x69\x6e\x67\x20\x70\x72\x6f\x66\x69\x6c\x65\x73\x2e"
);($__databaseInitialized=(0x0faa+ 3728-0x1e3a));foreach my $key (keys (
%__profiles)){delete ($__profiles{$key});}}sub 
__convertUsernamesInKeysToAbsoluteUsername{if ((($__userSidsInitialized==
(0x2286+ 1038-0x2693))or ($GLOBAL::DisableUsernameConversion==
(0x10a6+ 595-0x12f8)))){return;}Logger::debug (
"\x4e\x58\x50\x72\x6f\x66\x69\x6c\x65\x73\x44\x42\x3a\x20\x43\x6f\x6e\x76\x65\x72\x74\x69\x6e\x67\x20\x75\x73\x65\x72\x6e\x61\x6d\x65\x73\x20\x74\x6f\x20\x53\x49\x44\x73\x2e"
);foreach my $key (keys (%__profiles)){(my $convertedKey=$key);
convertUsernameInKeyToAbsoluteUsername ((\$convertedKey));if (($convertedKey ne 
$key)){($__profiles{$convertedKey}=$__profiles{$key});delete ($__profiles{$key})
;}}($__userSidsInitialized=(0x14c6+ 1123-0x1928));}sub 
convertUsernameInKeyToAbsoluteUsername{if (($GLOBAL::DisableUsernameConversion==
(0x011b+ 643-0x039d))){return;}(my $ref_key=shift (@_));if ((
__convertUsernameInNodeAndUserProfileKeyToAbsoluteUsername ($ref_key)==
(0x1a73+ 3032-0x264a))){return;}if ((
__convertUsernameInUserProfileKeyToAbsoluteUsername ($ref_key)==
(0x11a5+ 4162-0x21e6))){return;}}sub 
__convertUsernameInNodeAndUserProfileKeyToAbsoluteUsername{(my $ref_key=shift (
@_));if (($$ref_key=~ /(.*),(.*)/ )){(my $node=$1);(my $user=$2);if (($node=~ /\// )
){if ((__convertUsernameInUserProfileKeyToAbsoluteUsername ((\$user))==
(0x1007+ 5659-0x2621))){($$ref_key=(($node."\x2c").$user));}}return (
(0x0400+ 6714-0x1e39));}return ((0x0cb6+ 4133-0x1cdb));}sub 
__convertUsernameInUserProfileKeyToAbsoluteUsername{(my $ref_key=shift (@_));if 
(NXProfiles::isInternalKey ($$ref_key)){return ((0x0b01+ 6443-0x242c));}if ((
$$ref_key=~ /__group__/ )){return ((0x00e5+ 8654-0x22b3));}if (($$ref_key=~ /\// )
){return ((0x0383+ 3067-0x0f7e));}if (($$ref_key=~ /__nodegroup__/ )){return (
(0x0077+ 5781-0x170c));}if (($$ref_key=~ /__servergroup__/ )){return (
(0x0bcc+ 5362-0x20be));}if (($$ref_key=~ /__address__/ )){return (
(0x2531+ 367-0x26a0));}(my $username=NXLogin::getAbsoluteNameForUsername (
$$ref_key));($$ref_key=$username);return ((0x017c+ 5941-0x18b0));}sub 
reloadProfilesDB{($__databaseInitialized=(0x0124+ 9175-0x24fb));(
$__userSidsInitialized=(0x0c49+ 6099-0x241c));((%__profiles)=());__load ();if (
NXProfiles::isPropagatedRuleToOverwrite ()){NXProfiles::overwritePropagatedRules
 ();}}"\x3f\x3f\x3f";
